'
' Interface to a Microchip 23K256 serial SRAM
' Display the results on the serial terminal
'
' For use with the Crownhill Proton BASIC compiler on an 18F device
'
    Include "Amicus18.inc"                          ' Configure the compiler to use a PIC18F25K20 at 64MHz. i.e. An Amicus18 board

    $define SRAM_CS PORTC.0                         ' The 23K256 SRAM CS line is connected to this pin

    Include "23K256.inc"                            ' Load the SRAM interface macros into the program

    Dim wAddress As Word                            ' Holds the address to read and write from
    Dim bDataIn As Byte                             ' Holds the byte read from the SRAM
    Dim bIndex As Byte                              ' Used for string and SRAM indexing

    Dim sSourceString As String * 32                ' Create a source string
    Dim sDestString As String * 32                  ' Create a destination string
'-----------------------------------------------------------------------------
Main:
'
' ** Byte mode Demo
'
    HRSOut "** Byte Mode **\r\r"
    SRAM_WriteStatus(cModeByte)                     ' Configure the SRAM to Byte Mode
'
' Write 20 bytes to the SRAM starting at address 0
'
    wAddress = 0
    Repeat                                          ' Create a loop of 20 iterations
        SRAM_WriteByte(wAddress, wAddress.Byte0)    ' Write a byte to the specified address location in SRAM
        Inc wAddress                                ' Increment the address
    Until wAddress = 20                             ' Close the loop
'
' Read 20 bytes from the SRAM starting at address 0
'
    wAddress = 0
    Repeat                                          ' Create a loop of 20 iterations
        bDataIn = SRAM_ReadByte(wAddress)           ' Read a byte from the specified address location in SRAM
        HRSOut "Address: ", Dec5 wAddress, " : ", IHex2 bDataIn, 13 ' Display the results on the serial terminal
        DelayMS 10                                  ' Delay so we can see what's hapenning
        Inc wAddress                                ' Increment the address
    Until wAddress = 20                             ' Close the loop
'
' ** Page mode Demonstration
'
    HRSOut "\r** Page Mode **\r\r"
'
' Fill a string with ASCII characters
'
    sSourceString = "*   Written using Page mode   *"
    HRSOut "To SRAM:   ", sSourceString, 13         ' Display the source string on the serial terminal

    SRAM_WriteStatus(cModePage)                     ' Configure SRAM to Page mode
    SRAM_WritePage(2, 31, sSourceString)            ' Write data stored in sSourceString to page 2 of the SRAM
    SRAM_ReadPage(2, 31, sDestString)               ' Read from page 2 of the SRAM into bDestString

    HRSOut "From SRAM: ", sDestString, 13           ' Display the result on the serial terminal
'
' ** Sequence Mode Demonstration
'
    HRSOut "\r** Sequential Mode **\r\r"
'
' Fill a string with ASCII characters
'
    sSourceString = "*Written using Sequential mode*"

    HRSOut "To SRAM:   ", sSourceString, 13         ' Display the source string on the serial terminal

    SRAM_WriteStatus(cModeSeq)               ' Configure SRAM to Sequence Mode
    SRAM_WriteSeq($0100, 31, sSourceString)         ' Write to the SRAM the data stored in the bSRAM_PageRAM string
    SRAM_ReadSeq($0100, 31, sDestString)            ' Read from the SRAM starting from address 0

    HRSOut "From SRAM: ", sDestString, 13           ' Display the result on the serial terminal

